@@ -234,7 +234,7 @@ def linkify(string):
 
     rgx = re.compile('([^a-zA-Z0-9_:])(' + \
                      '|'.join(map(re.escape, linkmap)) + \
-                     ')([^a-aA-Z0-9_:])')
+                     ')([^a-zA-Z0-9_:])')
 
     def translateCodeLink(match):
         return match.group(1) + linkmap[match.group(2)] + match.group(3)
@@ -277,28 +277,26 @@ def getComment(m, urinode, classlist, proplist, instalist):
         # Add links to code documentation for identifiers
         markup = linkify(markup)
 
-        # Replace ext:ClassName with link to appropriate fragment
-        rgx = re.compile(spec_pre + ':([A-Z][a-zA-Z0-9_-]*)')
-        def translateClassLink(match):
+        # Transform prefixed names like eg:something into links if possible
+        rgx = re.compile('([a-zA-Z0-9_-]+):([a-zA-Z0-9_-]+)')
+        namespaces = getNamespaces(m)
+        def translateLink(match):
+            text   = match.group(0)
+            prefix = match.group(1)
+            name   = match.group(2)
             curie = match.group(0)
-            name  = curie[curie.find(':') + 1:]
-            uri   = spec_ns + name
-            if rdflib.URIRef(uri) not in classlist:
-                print("warning: Link to undefined class %s\n" % curie)
-            return '<a href="#%s">%s</a>' % (name, curie)
-        markup = rgx.sub(translateClassLink, markup)
-
-        # Replace ext:instanceName with link to appropriate fragment
-        rgx = re.compile(spec_pre + ':([a-z][a-zA-Z0-9_-]*)')
-        def translateInstanceLink(match):
-            curie = match.group(0)
-            name  = curie[curie.find(':') + 1:]
-            uri   = spec_ns + name
-            if (rdflib.URIRef(uri) not in instalist and
-                rdflib.URIRef(uri) not in proplist):
-                print("warning: Link to undefined instance/property %s\n" % curie)
-            return '<a href="#%s">%s</a>' % (name, curie)
-        markup = rgx.sub(translateInstanceLink, markup)
+            uri   = rdflib.URIRef(spec_ns + name)
+            if prefix == spec_pre:
+                if not (uri in classlist or uri in instalist or uri in proplist):
+                    print("warning: Link to undefined resource <%s>\n" % text)
+                return '<a href="#%s">%s</a>' % (name, curie)
+            elif prefix in namespaces:
+                return '<a href="%s">%s</a>' % (
+                    namespaces[match.group(1)] + match.group(2),
+                    match.group(0))
+            else:
+                return text
+        markup = rgx.sub(translateLink, markup)
 
         if have_lxml:
             try:
@@ -329,7 +327,7 @@ def getComment(m, urinode, classlist, proplist, instalist):
     c = findOne(m, urinode, rdfs.comment, None)
     if c:
         text = getLiteralString(getObject(c))
-        return xml.sax.saxutils.escape(text)
+        return '<p>%s</p>' % xml.sax.saxutils.escape(text)
 
     return ''
 
@@ -1039,7 +1037,7 @@ def load_tags(path, docdir):
 
     return linkmap
 
-def specgen(specloc, indir, style_uri, docdir, tags, instances=False, mode="spec"):
+def specgen(specloc, indir, style_uri, docdir, tags, instances=False, offline=False):
     """The meat and potatoes: Everything starts here."""
 
     global spec_url
@@ -1161,9 +1159,7 @@ def specgen(specloc, indir, style_uri, docdir, tags, instances=False, mode="spec
 
     template = template.replace('@REVISION@', version_string)
 
-    
-    header_files = ''
-    other_files  = ''
+    file_list = ''
     see_also_files = specProperties(m, spec, rdfs.seeAlso)
     see_also_files.sort()
     for f in see_also_files:
@@ -1175,21 +1171,22 @@ def specgen(specloc, indir, style_uri, docdir, tags, instances=False, mode="spec
             else:
                 continue  # Skip seeAlso file outside bundle
 
-        
-        entry = '<a href="%s">%s</a>' % (uri, uri)
+
+        if offline:
+            entry = uri
+        else:
+            entry = '<a href="%s">%s</a>' % (uri, uri)
         if uri.endswith('.h') or uri.endswith('.hpp'):
             name = os.path.basename(uri)
-            entry += ' (<a href="%s">Documentation</a>) ' % (
+            entry += ' - <a href="%s">Documentation</a> ' % (
                 docdir + '/' + name.replace('.', '_8') + '.html')
-            header_files += '<li>%s</li>' % entry
+            file_list += '<li>%s</li>' % entry
         else:
-            other_files += '<li>%s</li>' % entry
+            file_list += '<li>%s</li>' % entry
 
     files = ''
-    if header_files:
-        files += '<li>API<ul>%s</ul></li>' % header_files
-    if other_files:
-        files += '<li>Data<ul>%s</ul></li>' % other_files
+    if file_list:
+        files += '<li>Files<ul>%s</ul></li>' % file_list
 
     template = template.replace('@FILES@', files)
 
